.. py:currentmodule:: drdmannturb

Spectra and Eddy Lifetime Function Learning
===========================================

Please refer to :doc:`this UML diagram <./uml_drd>` to see how data classes are composed to inform the :py:class:`CalibrationProblem` classes. 

Uses of this class require the :py:class:`OnePointSpectraDataGenerator`, please refer to that documentation for specifics about data needed for spectra fitting. 

CalibrationProblem
------------------

.. autoclass:: drdmannturb.CalibrationProblem 
    :members:

OnePointSpectraDataGenerator 
----------------------------

.. autoclass:: drdmannturb.OnePointSpectraDataGenerator
    :members:

OnePointSpectra 
---------------

.. autoclass:: drdmannturb.OnePointSpectra
    :members:
